@@ -1,9 +1,11 @@
 package Net::Whois::Raw::Common;
 
 use Encode;
+use warnings;
 use strict;
 use Regexp::IPv6 qw($IPv6_re);
-require Net::Whois::Raw::Data;
+use Net::Whois::Raw::Data ();
+use Net::Whois::Raw ();
 
 use utf8;
 
@@ -61,14 +63,15 @@ sub write_to_cache {
         local $res->{text} = $res->{whois} if not exists $res->{text};
 
         next if defined $res->{text} && !$res->{text} || !defined $res->{text};
-        utf8::encode( $res->{text} );
+        my $enc_text = $res->{text};
+        utf8::encode( $enc_text );
         my $postfix = sprintf("%02d", $level);
         if ( open( my $cache_fh, '>', "$cache_dir/$query.$postfix" ) ) {
             print $cache_fh $res->{srv} ? $res->{srv} :
                 ( $res->{server} ? $res->{server} : '')
                 , "\n";
 
-            print $cache_fh $res->{text} ? $res->{text} : '';
+            print $cache_fh $enc_text ? $enc_text : '';
 
             close $cache_fh;
             chmod 0666, "$cache_dir/$query.$postfix";
@@ -78,22 +81,21 @@ sub write_to_cache {
 
 }
 
-
 # remove copyright messages, check for existance
 sub process_whois {
-    my ($query, $server, $whois, $CHECK_FAIL, $OMIT_MSG, $CHECK_EXCEED) = @_;
+    my ( $query, $server, $whois, $CHECK_FAIL, $OMIT_MSG, $CHECK_EXCEED ) = @_;
 
     $server = lc $server;
-    my ($name, $tld) = split_domain($query);
+    my ( $name, $tld ) = split_domain( $query );
 
     # use string as is
     no utf8;
 
     if ( $CHECK_EXCEED ) {
-        my $exceed = $Net::Whois::Raw::Data::exceed{$server};
+        my $exceed = $Net::Whois::Raw::Data::exceed{ $server };
 
         if ( $exceed && $whois =~ /$exceed/s) {
-            return $whois, "Connection rate exceeded";
+            return $whois, 'Connection rate exceeded';
         }
     }
 
@@ -102,23 +104,24 @@ sub process_whois {
         my %notfound = %Net::Whois::Raw::Data::notfound;
         my %strip = %Net::Whois::Raw::Data::strip;
 
-        my $notfound = $notfound{$server};
+        my $notfound = $notfound{ $server };
 
-        my @strip = $strip{$server} ? @{$strip{$server}} : ();
+        my @strip = $strip{ $server } ? @{ $strip{ $server } } : ();
         my @lines;
-MAIN:
-        foreach (split(/\n/, $whois)) {
+
+        MAIN:
+        for ( split /\n/, $whois ) {
             if ( $CHECK_FAIL && $notfound && /$notfound/ ) {
                 return undef, "Not found";
-            };
+            }
 
-            if ($OMIT_MSG) {
-                foreach my $re (@strip) {
-                    next MAIN if (/$re/);
+            if ( $OMIT_MSG ) {
+                for my $re ( @strip ) {
+                    next MAIN  if /$re/;
                 }
             }
 
-            push(@lines, $_);
+            push @lines, $_;
         }
 
         $whois = join "\n", @lines, '';
@@ -130,16 +133,16 @@ MAIN:
         }
     }
 
-    if ( defined $Net::Whois::Raw::Data::postprocess{$server} ) {
-        $whois = $Net::Whois::Raw::Data::postprocess{$server}->($whois);
+    if ( defined $Net::Whois::Raw::Data::postprocess{ $server } ) {
+        $whois = $Net::Whois::Raw::Data::postprocess{ $server }->( $whois );
     }
 
-    if ( defined $Net::Whois::Raw::POSTPROCESS{$server} ) {
-        $whois = $Net::Whois::Raw::POSTPROCESS{$server}->($whois);
+    if ( defined $Net::Whois::Raw::POSTPROCESS{ $server } ) {
+        $whois = $Net::Whois::Raw::POSTPROCESS{ $server }->( $whois );
     }
 
-    if ( defined $Net::Whois::Raw::Data::codepages{$server} ) {
-        $whois = decode( $Net::Whois::Raw::Data::codepages{$server}, $whois );
+    if ( defined $Net::Whois::Raw::Data::codepages{ $server } ) {
+        $whois = decode( $Net::Whois::Raw::Data::codepages{ $server }, $whois );
     }
     else {
         utf8::decode( $whois );
@@ -148,7 +151,6 @@ MAIN:
     return $whois, undef;
 }
 
-
 # get whois-server for domain / tld
 sub get_server {
     my ($dom, $is_ns, $tld) = @_;
@@ -464,7 +466,6 @@ sub parse_www_content {
         }
     }
     elsif ( $tld eq 'tj' && $url =~ m|^http\://get\.tj| ) {
-
         $resp = decode_utf8( $resp );
 
         if ($resp =~ m|<!-- Content //-->\n(.+?)<!-- End Content //-->|s ) {
@@ -507,10 +508,9 @@ sub parse_www_content {
 
     }
     elsif ( $tld eq 'tj' && $url =~ m|\.nic\.tj/cgi/whois| || $url =~ m|62\.122\.137\.16| ) {
-
         $resp = decode_utf8( $resp );
 
-        if ( $resp =~ m{ <table [^>]*? > (.+) (:? </table> )? }sxmi ) {
+        if ( $resp =~ m{ <table [^>]*? > (.+) (:? </table> ) }sxmi ) {
             $resp = $1;
             $resp =~ s|</?tr>||ig;
             $resp =~ s|<td>| |ig;
